# North Korean Hackers Deploy New Malicious Python Packages in PyPI Repository
## Researchers uncover 3 more malicious Python packages in PyPI repository under VMConnect campaign.
## Information:

+ Link: https://thehackernews.com/2023/08/north-korean-hackers-deploy-new.html
+ Source: The Hacker News
+ Author: THN
+ Date published: 31 August 2023, 18:16
+ Date scraped: 31 August 2023, 13:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgYK4rB4iyOEWACPwtlHrEKpl13ijb5lSGRoJG-5HjcmWtelsjSphOxwEsN6fdMd9YyRJ7sbniCZv337heJz-6dcyge9hubQh0jymdHjzuWxun4GYr0YJiMUXqxK84rPGcm5L7OXKWekpZTeDUKEOpFQX_57hJ6OGrQ--10KaDLJ0UqMCwZ7QvEk3yitbY_/s728-e3650/code.jpg)


Three additional malicious Python packages have been discovered in the Package Index (PyPI) repository as part of an ongoing malicious software supply chain campaign called **VMConnect**, with signs pointing to the involvement of North Korean state-sponsored threat actors.


The [findings](https://www.reversinglabs.com/blog/vmconnect-supply-chain-campaign-continues) come from ReversingLabs, which detected the packages tablediter, request-plus, and requestspro.


First disclosed at the start of the month by the company and Sonatype, [VMConnect](https://thehackernews.com/2023/08/malicious-npm-packages-found.html) refers to a collection of Python packages that mimic popular open-source Python tools to download an unknown second-stage malware.


The latest tranche is no different, with ReversingLabs noting that the bad actors are disguising their packages and making them appear trustworthy by using typosquatting techniques to impersonate prettytable and requests and confuse developers.


The nefarious code within tablediter is designed to run in an endless execution loop in which a remote server is polled periodically to retrieve and execute a Base64-encoded payload. The exact nature of the payload is presently unknown.


One of the main changes introduced in tablediter is the fact that it no longer triggers the malicious code immediately upon installation of the package so as to evade detection by security software.


"By waiting until the designated package is imported and its functions called by the compromised application, they avoid one form of common, behavior based detection and raise the bar for would-be defenders," security researcher Karlo Zanki said.


The other two packages, request-plus and requestspro, pack in the ability to collect information about the infected machine and transmit it to a command-and-control (C2) server.


[![Cybersecurity](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhm307Hkf3ltRaZ9aYPMAMkarRfeZqeb9lr76AYj5TyW4mi1Dhgxqe-mGbmRiDsl7xCcRfhBhMR0oDROzrIeBEpQTwhOju46GCQUVipAD8RLNXsz_A-luP30_JCYzIhfAVq7jXv4hyiDNxY8cYfqj0ucoSd1JH2jJLslSnVZ7_PIAQ9E_aUo-1_EmYeOKR3/s728-e3650/2.png)](https://thn.news/edWGl41h)
Following this step, the server responds back with a token, which the infected host sends back to a different URL on the same C2 server, ultimately receiving in return a double-encoded Python module and a download URL.


It's suspected that the decoded module downloads the next stage of the malware from the URL provided.


A Complex Web of Connections Leading to North Korea[#](#a-complex-web-of-connections-leading-to-north-korea)
------------------------------------------------------------------------------------------------------------


The use of a token-based approach to fly under the radar mirrors an [npm campaign](https://thehackernews.com/2023/06/new-ongoing-campaign-targets-npm.html) that Phylum disclosed in June, and which has since been connected to North Korean actors. Microsoft-owned GitHub [attributed](https://thehackernews.com/2023/07/north-korean-state-sponsored-hackers.html) the attacks to a threat actor it calls Jade Sleet, which is also known as TraderTraitor or UNC4899.


TraderTraitor is one of North Korea's prominent cyber weapons in its [hack for profit schemes](https://thehackernews.com/2022/04/fbi-us-treasury-and-cisa-warns-of-north.html), and has a long and successful history of targeting cryptocurrency companies and other sectors for financial gain.


The potential connections raise the possibility that this is a common tactic that the adversaries are adopting to selectively deliver a second-stage malware based on certain filtering criteria.


The links to North Korea are also corroborated by the fact that infrastructure overlaps have been discovered between the npm engineering campaign and the [JumpCloud hack](https://thehackernews.com/2023/07/north-korean-nation-state-actors.html) of [June 2023](https://www.reversinglabs.com/blog/more-malicious-npm-packages-found-in-wake-of-jumpcloud-supply-chain-hack).


What's more, ReversingLabs said it found a Python package named py\_QRcode which contains malicious functionality that is very similar to that found in the VMConnect package.


py\_QRcode, as it happens, is said to have been employed as the starting point of a separate attack chain targeting developers of cryptocurrency exchange businesses in late May 2023. JPCERT/CC, last month, attributed it to another North Korean activity codenamed [SnatchCrypto](https://thehackernews.com/2022/12/bluenoroff-apt-hackers-using-new-ways.html) (aka CryptoMimic or [DangerousPassword](https://blogs.jpcert.or.jp/en/2023/05/dangerouspassword.html)).


"This Python malware runs in Windows, macOS, and Linux environments, and it checks the OS information and changes the infection flow depending on it," the agency [said](https://blogs.jpcert.or.jp/en/2023/07/dangerouspassword_dev.html), describing the actor as unique for targeting the developer environment with a variety of platforms.


[![Cybersecurity](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgNmNiBV8c8Rp0Xy6N9lCX9JL2cBlrjkSeuW4JhgOVQ3mKTsYV4pPvh3nDz32D97D8XcWQ53EJ1p4n2VX0gZH_YrBZBqElUMfzFWgb50P8lv1iac_1f-p5liZzC1ISVWJygv2s1Qm36rOHwk_kPXUNNT3nbSDr144QYZ6XGq0aXRDOrFfSlUnHnc0x4Fe_F/s728-e3650/cis-d.gif)](https://thn.news/Cr7gkMdK)
Another notable aspect is that the attacks against macOS systems culminated in the deployment of [JokerSpy](https://thehackernews.com/2023/06/japanese-cryptocurrency-exchange-falls.html), a novel backdoor that first came to light in June 2023.


That's not all. In June 2023, cybersecurity firm SentinelOne detailed another piece of malware dubbed [QRLog](https://github.com/birminghamcyberarms/QRLog#english) that comes with identical functionality as that of py\_QRcode and references the domain www.git-hub[.]me, which has also been seen in connection with a [JokerSpy infection](https://thehackernews.com/2023/06/researchers-discover-new-sophisticated.html).


"The JokerSpy intrusions reveal a threat actor with the ability to write functional malware across several different languages – Python, Java, and Swift – and target multiple operating systems platforms," security researcher Phil Stokes [noted](https://www.sentinelone.com/blog/jokerspy-unknown-adversary-targeting-organizations-with-multi-stage-macos-malware/) at the time.


Cybersecurity researcher Mauro Eldritch, who first detected the QRLog malware, [said](https://www.clarin.com/tecnologia/hecho-corea-norte-descubren-nuevo-virus-funciona-molotov-digital_0_fR36LRX5mj.html) there is evidence to suggest that the malware is the work of an adversary known as Labyrinth Chollima, which is a sub-group of the infamous [Lazarus Group](https://thehackernews.com/2023/08/lazarus-group-exploits-critical-zoho.html).


"This is just another in a line of malicious attacks targeting users of the PyPI repository," Zanki said, adding "threat actors continue to use the Python Package Index (PyPI) repository as a distribution point for their malware."


  





## Tags:
***urls***: http://www.git-hub.me

### Autogenerated tags:
[[malware]] [[pypi]] [[vmconnect]] [[reversinglabs]] [[tablediter]] [[url]] [[py_qrcode]] [[jokerspy]]
