# New MoonBounce UEFI malware used by APT41 in targeted attacks
## Security analysts have discovered and linked MoonBounce, "the most advanced" UEFI firmware implant found so far in the wild, to the Chinese-speaking APT41 hacker group (also known as Winnti).
## Information:

+ Link: https://www.bleepingcomputer.com/news/security/new-moonbounce-uefi-malware-used-by-apt41-in-targeted-attacks/
+ Source: Bleeping Computer
+ Author: Bill Toulas
+ Date published: 20 January 2022, 12:55
+ Date scraped: 20 January 2022, 13:00

## Article:
![Main article image](https://www.bleepstatic.com/content/hl-images/2022/01/20/motherboard.jpg)


![motherboard UEFI malware](https://www.bleepstatic.com/content/hl-images/2022/01/20/motherboard.jpg?rand=1686171829)


Security analysts have discovered and linked MoonBounce, "[the most advanced](https://twitter.com/oct0xor/status/1484143385518780417)" UEFI firmware implant found in the wild so far, to the Chinese-speaking APT41 hacker group (also known as Winnti).


[APT41](https://www.bleepingcomputer.com/tag/winnti/) is a notorious hacking group that has been active for at least a decade and is primarily known for its stealthy cyber-espionage operations against high-profile organizations from various industry sectors.


The discovery of **MoonBounce** is the work of researchers at Kaspersky, who have published a detailed technical report on their findings.


A sophisticated UEFI implant
----------------------------


UEFI (Unified Extensible Firmware Interface) is a technical specification that helps interface operating system (OS) and firmware software in computer systems.


Being able to plant malicious code called "UEFI bootkit," in the firmware is an excellent way to remain hidden from AVs and any security tools running on the OS level.


This has been done multiple times before, with two recent examples being the [FinFisher malware](https://www.bleepingcomputer.com/news/security/finfisher-malware-hijacks-windows-boot-manager-with-uefi-bootkit/) and the [ESPecter backdoor](https://www.bleepingcomputer.com/news/security/new-uefi-bootkit-used-to-backdoor-windows-devices-since-2012/).


Generally, these tools hijack the booting sequence and initialize before the OS security components. They are very persistent because they nest in areas that can't be erased, like a reserved space on the disk.


In the case of MoonBounce, the implanting location is on the SPI flash memory of the motherboard, so not even a hard disk replacement can uproot it.


The laced firmware component is CORE\_DXE, which is called during the early phase of the UEFI boot sequence.



![Overview of MoonBounce functions](https://www.bleepstatic.com/images/news/u/1220909/Diagrams/uefi-diagram.png)**Overview of MoonBounce functions**  
*Source: Kaspersky*
"The source of the infection starts with a set of hooks that intercept the execution of several functions in the EFI Boot Services Table, namely AllocatePool, CreateEventEx, and ExitBootServices," explains [Kaspersky in the report](https://media.kasperskycontenthub.com/wp-content/uploads/sites/43/2022/01/19115831/MoonBounce_technical-details_eng.pdf).


"Those hooks are used to divert the flow of these functions to malicious shellcode that is appended by the attackers to the CORE\_DXE image, which in turn sets up additional hooks in subsequent components of the boot chain, namely the Windows loader."


"This multistage chain of hooks facilitates the propagation of malicious code from the CORE\_DXE image to other boot components during system startup, allowing the introduction of a malicious driver to the memory address space of the Windows kernel."


This driver runs during the OS kernel initiation and injects the malware into an svchost.exe process. The malware has fully initialized as soon as the computer is up and running.


Next, it communicates to a hardcoded C2 URL address and attempts to fetch the next stage payload, which will run in memory.


Kaspersky couldn't retrieve that payload for analysis or figure out how exactly the actors infected the UEFI firmware in the first place.


Campaign targets and goals
--------------------------


The telemetry data reveals that these attacks were highly targeted, and Kaspersky only detected the firmware rootkit in a single case.



![Timeline of infection on the compromised firm](https://www.bleepstatic.com/images/news/u/1220909/Diagrams/infected-timeline.jpg)**Timeline of infection on the compromised firm**  
*Source: Kaspersky*
However, Kaspersky found multiple malware samples and loaders in other machines in the same network, but those were non-UEFI implants.


Examples include the Microcin backdoor, the Mimikat credential stealer, the Go implant, the StealthMutant loader, and the ScrambleCross malware.



![Infrastructure diagram linking ScrambleCross with MoonBounce](data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==)**Infrastructure diagram linking ScrambleCross with MoonBounce**  
*Source: Kaspersky*
As for who was targeted, the security firm mentions an organization in control of several enterprises dealing with transportation technology.


The adversaries' main goal was to establish a lengthy foothold within the network and conduct cyber-espionage by exfiltrating valuable data to the C2 server.


In this context, the APT41 operators performed analytical network reconnaissance and moved laterally where possible while at the same time wiping traces of their malicious activity.


APT41 still going strong
------------------------


Kaspersky found plenty of evidence linking MoonBounce to APT41, ranging from the deployment of the ScrambleCross malware itself to unique certificates retrieved from its C2 servers which match [previous FBI reports](https://s3.documentcloud.org/documents/7210602/FLASH-AC-000133-TT-Published.pdf) on APT41 activity.


While the U.S. Department of Justice identified and [charged five APT41 members](https://www.bleepingcomputer.com/news/security/us-charges-chinese-winnti-hackers-for-attacking-100-plus-companies/) in September 2020, the existence of MoonBounce and the operation around it proves the threat actors weren't discouraged by the legal pressure.


APT41 remains a sophisticated threat actor who can develop evasive tools that bypass even the most impenetrable corporate networks.


With UEFI threats now getting more traction, Kaspersky advises potential to take the following measures to defend against attackers using MoonBounce or similar malware:


* Enable Secure Boot by default
* Update firmware regularly
* Verify that BootGuard is enabled
* Enable Trust Platform Modules





## Tags:


### Autogenerated tags:
[[kaspersky]] [[moonbounce]] [[uefi]] [[malware]] [[apt41]] [[core_dxe]] [[c2]] [[scramblecross]]
