# Cuttlefish targets enterprise-grade SOHO routers
## Cuttlefish malware targets enterprise-grade and small office/home office (SOHO) routers to harvest public cloud authentication data.
## Information:

+ Link: https://securityaffairs.com/162603/malware/cuttlefish-malware-targets-routers.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 01 May 2024, 17:43
+ Date scraped: 01 May 2024, 18:13

## Article:
![Main article image](https://securityaffairs.com/wp-content/uploads/2024/05/image.png)



Researchers at Lumen’s Black Lotus Labs discovered a new malware family, named Cuttlefish, which targets enterprise-grade and small office/home office (SOHO) routers to harvest public cloud authentication data from internet traffic.


The malware creates a proxy or VPN tunnel on the compromised router to exfiltrate data, and then uses stolen credentials to access targeted resources. 



Cuttlefish has a modular structure, it was designed to primarily steal authentication data from web requests passing through the router from the local area network (LAN). The malicious code can also perform DNS and HTTP hijacking within private IP spaces. Additionally, it can interact with other devices on the LAN and transfer data or deploy new agents. The researchers observed similarities in code and build paths with a previously reported malware called [HiatusRat](https://securityaffairs.com/149723/intelligence/hiatusrat-campaign-taiwan-us.html), linked to China. Although there’s code overlap, no shared victimology has been observed, suggesting that these malware families operate concurrently.


*“The Cuttlefish malware offers a zero-click approach to capturing data from users and devices behind the targeted network’s edge. Any data sent across network equipment infiltrated by this malware, is potentially exposed.” [reads the Lumen’s Black Lotus researchers](https://blog.lumen.com/eight-arms-to-hold-you-the-cuttlefish-malware/). “What makes this malware family so insidious is the ability to perform HTTP and DNS hijacking for connections to private IP addresses. Cuttlefish lies in wait, passively sniffing packets, acting only when triggered by a predefined ruleset.”*


The malware has been active since at least July 27, 2023, with indications of earlier versions. The recent campaign spanned from October 2023 to April 2024. The experts noticed that the infection chain was distinct, with 99% of infections originating in Turkey, primarily from two major telecommunications providers. These providers comprised around 93% of infections, totaling 600 unique IP addresses. Other non-Turkish victims included IP addresses likely belonging to clients of global satellite phone providers and a potential US-based data center.


The researchers have yet to determine the initial access vector, however, they believe threat actors could have exploited known vulnerabilities or carried out brute-forcing credentials. Upon gaining access to the routers, the attackers deploy a bash script that gathers certain host-based data to send to the C2. The bash script also downloads and executes Cuttlefish.


The binary analyzed by the researchers is compiled for all major architectures used by SOHO operating systems.


[![Cuttlefish malware](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/05/image.png?resize=1024%2C536&ssl=1)](https://i0.wp.com/securityaffairs.com/wp-content/uploads/2024/05/image.png?ssl=1)


The malware passively monitors network packets for “credential markers,” including usernames, passwords, and authentication tokens. Cuttlefish primarily targets public cloud-based services such as Alicloud, AWS, Digital Ocean, CloudFlare, and BitBucket.


The Black Lotus Labs report highlights that targeted services are used for storing sensitive data. This approach enables threat actors to potentially copy data from cloud resources lacking the logging or controls commonly present in traditional network perimeters.


The malware store the stolen data in the log, then when the log file of filtered traffic reaches a specified size, Cuttlefish compresses it using gzip and uploads it to the C2 server using a computed uuid and a predefined value of “tid”.


Cuttlefish redirects DNS requests for private IP addresses to a specified DNS server and manipulates HTTP requests to reroute traffic to an infrastructure under the control of its operators using HTTP 302 error codes. This capability suggests that Cuttlefish can hijack internal or site-to-site traffic, enabling access to secured resources not exposed on the Internet.


*“Cuttlefish represents the latest evolution in passive eavesdropping malware for edge networking equipment, allowing an actor to adapt and overcome the TLS configurations adopted by more modern enterprises.” concludes the report. “We also believe these innovations are the next generation in malware capabilities; the ability to eavesdrop and perform DNS and HTTP hijacking has seldom been observed – the few publicly identified campaigns include [ZuoRat](https://blog.lumen.com/zuorat-hijacks-soho-routers-to-silently-stalk-networks/), [VPNFilter](https://blog.talosintelligence.com/vpnfilter/), [Attor](https://www.welivesecurity.com/2019/10/10/eset-discovers-attor-spy-platform/), and [Plead](https://www.welivesecurity.com/2019/05/14/plead-malware-mitm-asus-webstorage/). However, this is the first instance where we have seen rules specifically designed to seek out private IP connections to hijack.”*



[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs) and [Mastodon](https://infosec.exchange/@securityaffairs)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, malware)**





---




---





## Tags:


### Autogenerated tags:
[[malware]] [[ip]] [[dns]] [[http]]
