# European firm DSIRF behind the attacks with Subzero surveillance malware
## Microsoft linked a private-sector offensive actor (PSOA) to attacks using multiple zero-day exploits for its Subzero malware. The Microsoft Threat Intelligence Center (MSTIC) and the Microsoft Security Response Center (MSRC) researchers linked a threat group known as Knotweed to an Austrian surveillance firm named DSIRF, known for using multiple Windows and Adobe zero-day exploits. The […]
## Information:

+ Link: https://securityaffairs.co/wordpress/133736/malware/dsirf-behind-subzero-malware.html
+ Source: Security Affairs
+ Author: Pierluigi Paganini
+ Date published: 28 July 2022, 11:04
+ Date scraped: 28 July 2022, 12:00

## Article:
![Main article image](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/07/Subzero-malware-Fig1-Valid-digital-signature-from-DSIRF.png?resize=300%2C253&ssl=1)


The Microsoft Threat Intelligence Center (MSTIC) and the Microsoft Security Response Center (MSRC) researchers linked a threat group known as Knotweed to an Austrian surveillance firm named DSIRF, known for using multiple Windows and Adobe zero-day exploits. The group targets entities in Europe and Central America with a surveillance tool dubbed Subzero.


The [DSIRF website](https://web.archive.org/web/20220713203741/https:/dsirf.eu/about/) states the provide services*“to multinational corporations in the technology, retail, energy and financial sectors*” and that they have “*a set of highly sophisticated techniques in gathering and analyzing information.*” They publicly offer several services including “*an enhanced due diligence and risk analysis process through providing a deep understanding of individuals and entities”*and *“highly sophisticated Red Teams to challenge your company’s most critical assets.”*


Microsoft states that [multiple](https://www.intelligenceonline.com/surveillance--interception/2022/04/06/after-finfisher-s-demise-berlin-explores-cyber-tool-options,109766000-art) [news](https://www.focus.de/politik/vorab-aus-dem-focus-volle-kontrolle-ueber-zielcomputer-das-raetsel-um-die-spionage-app-fuehrt-ueber-wirecard-zu-putin_id_24442733.html) [reports](https://netzpolitik.org/2021/dsirf-wir-enthuellen-den-staatstrojaner-subzero-aus-oesterreich) have linked the company to the Subzero malware toolset used to hack a broad range of devices, phones, computers, and network and internet-connected devices. 


The researchers found evidence that links DSIRF to the Knotweed’s operation, including the C2 infrastructure used by Subzero, and code signing certificate issued to DSIRF that is used to sign an exploit.



[![Subzero malware Fig1-Valid-digital-signature-from-DSIRF.](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/07/Subzero-malware-Fig1-Valid-digital-signature-from-DSIRF.png?resize=375%2C253&ssl=1)](https://i0.wp.com/securityaffairs.co/wordpress/wp-content/uploads/2022/07/Subzero-malware-Fig1-Valid-digital-signature-from-DSIRF.png?ssl=1)


Microsoft reported Subzero attacks against Microsoft customers in Austria, the United Kingdom, and Panama. The targeted entities are law firms, banks, and strategic consultancies.


MSTIC states that the KNOTWEED’s Subzero malware was deployed in multiple ways, the IT giant referred the different stages of Subzero malware as *Jumplump*for the persistent loader and *Corelump*for the main malware.


Once compromised the system, threat actors drop the Corelump downloader and inject it directly in memory to evade detection. It supports multiple features, including keylogging, capturing screenshots, exfiltrating files, running a remote shell, and running arbitrary plugins downloaded from KNOTWEED’s C2 server. 


Microsoft researchers observed a variety of post-compromise actions on infected systems:


* Setting of UseLogonCredential to “1” to enable plaintext credentials
* Credential dumping via comsvcs.dll
* Attempt to access emails with dumped credentials from a KNOTWEED IP address
* Using Curl to download KNOTWEED tooling from public file shares such as vultrobjects[.]com
* Running PowerShell scripts directly from a GitHub gist created by an account associated with DSIRF


Researchers from threat intelligence firm RiskIQ, using passive DNS data related to Knotweed attacks, linked the C2 infrastructure used by the malware since February 2020 to DSIRF.


One of the zero-day exploits used in Knotweed attacks was triggering the recently patched [CVE-2022-22047](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22047) issue. The attackers used this exploit to escalate privileges, escape sandboxes, and gain system-level code execution on the vulnerable system.


*“In 2021, MSRC received a report of two Windows privilege escalation exploits ([CVE-2021-31199](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-31199) and [CVE-2021-31201](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-31201)) being used in conjunction with an Adobe Reader exploit ([CVE-2021-28550](https://helpx.adobe.com/security/products/acrobat/apsb21-29.html)), all of which were patched in June 2021. MSTIC was able to confirm the use of these in an exploit chain used to deploy Subzero.” [reads the report](https://www.microsoft.com/security/blog/2022/07/27/untangling-knotweed-european-private-sector-offensive-actor-using-0-day-exploits/). £We were later able to link the deployment of Subzero to a fourth exploit, one related to a Windows privilege escalation vulnerability in the Windows Update Medic Service ([CVE-2021-36948](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2021-36948)), which allowed an attacker to force the service to load an arbitrary signed DLL. The malicious DLL used in the attacks was signed by ‘DSIRF GmbH’.”*


Below is the list of recommendations published by Microsoft for its customers to prevent Subzero infections:


* All customers should prioritize patching of [CVE-2022-22047](https://msrc.microsoft.com/update-guide/vulnerability/CVE-2022-22047).
* Confirm that Microsoft Defender Antivirus is updated to security intelligence update **1.371.503.0** or later to detect the related indicators.
* Use the included indicators of compromise to investigate whether they exist in your environment and assess for potential intrusion.
* [Change Excel macro security settings](https://support.microsoft.com/office/change-macro-security-settings-in-excel-a97c09d2-c082-46b8-b19f-e8621e8fe373) to control which macros run and under what circumstances when you open a workbook. Customers can also [stop malicious XLM or VBA macros](https://www.microsoft.com/security/blog/2021/03/03/xlm-amsi-new-runtime-defense-against-excel-4-0-macro-malware/) by ensuring runtime macro scanning by Antimalware Scan Interface ([AMSI](https://docs.microsoft.com/windows/win32/amsi/antimalware-scan-interface-portal)) is on. This feature—enabled by default—is on if the Group Policy setting for Macro Run Time Scan Scope is set to “Enable for All Files” or “Enable for Low Trust Files”.
* Enable multifactor authentication (MFA) to mitigate potentially compromised credentials and ensure that MFA is enforced for all remote connectivity. *Note:* Microsoft strongly encourages all customers download and use password-less solutions like [Microsoft Authenticator](https://www.microsoft.com/account/authenticator/) to secure accounts.
* Review all authentication activity for remote access infrastructure, with a particular focus on accounts configured with single factor authentication, to confirm authenticity and investigate any anomalous activity.


*“Microsoft will continue to monitor KNOTWEED activity and implement protections for our customers. The current detections and IOCs detailed below are in place and protecting Microsoft customers across our security products. Additional advanced hunting queries are also provided below to help organizations extend their protections and investigations of these attacks.” concludes Microsoft.*


Follow me on Twitter: [**@securityaffairs**](https://twitter.com/securityaffairs) and [**Facebook**](https://www.facebook.com/sec.affairs)




|  |  |
| --- | --- |
|  |  |




[**Pierluigi Paganini**](http://www.linkedin.com/pub/pierluigi-paganini/b/742/559)


**(**[**SecurityAffairs**](http://securityaffairs.co/wordpress/)**–** **hacking, Subzero malware)**




 
  


---


  




## Tags:
***CVE's***: CVE-2021-36948 CVE-2021-31199 CVE-2022-22047 CVE-2021-28550 CVE-2021-31201
***urls***: http://vultrobjects.comRunning

### Autogenerated tags:
[[microsoft]] [[dsirf]] [[malware]] [[windows]] [[mstic]] [[c2]]
