# Analysis and Config Extraction of Lu0Bot, a Node.js Malware with Considerable Capabilities
## Breaking down Lu0Bot's layers: From BAT files to unique domain assembly. Analysts share insights into the unconventional methods used by this Node.js
## Information:

+ Link: https://thehackernews.com/2023/10/analysis-and-config-extraction-of.html
+ Source: The Hacker News
+ Author: The Hacker News
+ Date published: 05 October 2023, 16:18
+ Date scraped: 05 October 2023, 11:01

## Article:
![Main article image](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEg77nZah7GihbxEYfhDfg_D7BsSyDhfnAVUlropXee_OlE64ejfNIYoRDY6UEQGtB-ChbOWifU1UIGiIKFi-LzU13Cs4G-UI5J_lvWvICG1IJJe0eAyl9OGoTq1S4chMH7uhxf9Ht3RH5BSi6ziACMCyNxEC91vm_94Ue26V_JZ7LetFpN0yilE1YAQCnM/s728-rw-ft-e30/header.jpg)


Nowadays, more malware developers are using unconventional programming languages to bypass advanced detection systems. The Node.js malware Lu0Bot is a testament to this trend.


By targeting a platform-agnostic runtime environment common in modern web apps and employing multi-layer obfuscation, Lu0Bot is a serious threat to organizations and individuals.


Although currently, the malware has low activity, the attackers are likely waiting for the right moment to strike.


To be prepared for any future scenario, a team of analysts conducted an in-depth technical analysis of one of the recent samples of Lu0Bot and [published an article](https://any.run/cybersecurity-blog/lu0bot-analysis/?utm_source=hacker_news&utm_medium=article&utm_campaign=lu0bot0928&utm_content=linktoblog) documenting their process.


Here's an overview of their research.


Static analysis of the Lu0Bot sample [#](#static-analysis-of-the-lu0bot-sample)
-------------------------------------------------------------------------------


The [sample](https://app.any.run/tasks/4696b947-92f0-4413-95dc-644c45ca99a6/?utm_source=hacker_news&utm_medium=article&utm_campaign=lu0bot0928&utm_content=task/) under investigation used an SFX packer, a self-extracting archive that can be opened with any archive utility. Its contents were explored individually.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhO9o0gRJclLyl8p13nTTLJ_vJY9LoWJoxjLEaW9gKBKVxqMwkLPonZETVqfUlApYDC7GLa5JlD_4KRt4bzbeI3BBYjvHLOfgYzBSgwwUgvy55FehfGnwtuzyiWZu24xFxbTY9_JfC8q6aPnWGPIwf4IwIhWCN1ehFdZ8VZabIIyBPNtvJ8Py-3gfAU2uo/s728-rw-ft-e30/image01.png)
### **1. BAT-file**[#](#1-batfile)



![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjJm5zhUo7eEamnVpG3KVjcMcNoR9zfobClNXoywZjAGWzB6YANixtCNLAT3nL7RDpvpmk659Vpjq7y5oBy72ZUBlPpz04KLK3Gia6_Kez_cBEeJHhiFkEZI5qaYfb0UmqnYc9mTQWgIEelwBXK8Cckq-E2bl1-D3zpAN5I6cp12wGY81IUIMaDjEcP06E/s728-rw-ft-e30/image02.png)
The first line in the file contained a comment that remained unclear and was not referenced later.


Next, the EXE file bundled multiple files, including a Node interpreter called fjlpexyjauf.exe.


Then, the interpreter received a file with bytes and a number (%1% in the screenshot) that likely served as the encryption key for the byte file.


### **2. eqnyiodbs.dat files**[#](#2-eqnyiodbsdat-files)



The file was divided into byte blocks, which were then merged to create the Node interpreter.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh3pb1_fO-HaNDBXN1o5CBwPsjBSRAay7OtJAOMSRed1uhtk33qzNBrSQVWcKGg31ZBzif6NbvHnFNGi55qjwJxW9R98YhVoB9n-OqQjry6ZJNl6WUPF1CEruIrKjH1Xs5HW1ijTFNIlchOB_3ZYTqWC4bCybWH6cBV8pRg198mRyIFtupiYjG8BlUYIWk/s728-rw-ft-e30/image03.png)
### **3. lknidtnqmg.dat file** [#](#3-lknidtnqmgdat-file)



This file had encrypted bytes in Base64, which could be decrypted using the given input number.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhq51xevlbO7PcxYmOCNZDZAQ9jwjD5E6VqYdSlRXGZRGWvGK70meoxDsOA5kfKWFKJK05GrUf1JHfKAeXDRMt74aJhWBXOoEHk_8KhFuHuKyF76Af-hEwbmUKUw8Jc2ZDctU54bTVBNZZM6E2SiAvnntkDN1RgRahMIwb_N2fo18YVS0-0HI1fOgsCOJk/s728-rw-ft-e30/image04.png)
### **4. gyvdcniwvlu.dat file** [#](#4-gyvdcniwvludat-file)



This driver allowed 32-bit programs on x64 systems to convert key scan codes into Unicode characters, likely used for keylogging functionality in the main process.


Dynamic malware analysis of Lu0Bot in ANY.RUN [#](#dynamic-malware-analysis-of-lu0bot-in-anyrun)
------------------------------------------------------------------------------------------------


The next step involved investigating the EXE file and lknidtnqmg.dat in [the ANY.RUN interactive malware](https://any.run/?utm_source=hacker_news&utm_medium=article&utm_campaign=lu0bot0928&utm_content=landing) sandbox to monitor their behavior and either decrypt the bytes or locate them decrypted in the process memory.


The analysis revealed that, upon execution, the main process started a BAT file that launched an EXE file. The code accepted encrypted JS input and gathered system data using WMIC, including information about process execution location, which aligned with the T1047 MITRE technique.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjSpCv0jrLFxI8lbMsSlbUzVXtYGW0OWktQsBk0SoNDFaczq4eanivm6-ZhzHnf8z03paXCxu_C4jlx60Ll8YRDv3b-4clTPqX-ySqX09pCN_IpRViX4mOeEfmlR4bVr4a2pfSewxjewujjlsWGoJmi59bJkNfIaJQ2ntQpd1YFbyU68l9qVWloEjjBk7U/s728-rw-ft-e30/image05.png)
It was discovered that the interpreter was copied to the startup folder. The connection to the domain continued after the system restarted, allowing the bot to remain operational.


Additionally, the malware demonstrated a unique approach to domain connection by assembling various parts into a single entity within the JS code.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEhIsYOx456ORHt1FRDK8TU4R3TPUahJUxIUqteO1f09hkJWbceOuCIuc4_ma3T2hmy5nyEdE4afimEsfJags5GgV7AXfF4VdRwGysICefUxbHAnEdnSFuBe0nKqi9W52bZGiFrhl5jKlkjq8PcWzoenw7aO271wsip7us7Vke_cLoX3scXfNqn29jiWz3k/s728-rw-ft-e30/image06.png)
Malware Analysis[Use a 14-day free trial to analyze malware in the ANY.RUN interactive sandbox.](https://app.any.run/#register/?utm_source=hacker_news&utm_medium=article&utm_campaign=xworm0923&utm_content=app)Work together with your team in a private mode. Interact with files and links in a dedicated VM to expose their malicious behavior. Collect fresh IOCs and configs in seconds.

[Start a free trial](https://any.run/demo/?utm_source=hacker_news&utm_medium=article&utm_campaign=lu0bot0928&utm_content=demo) **Technical analysis of Lu0Bot malware using a disassembler and debugger** [#](#technical-analysis-of-lu0bot-malware-using-a-disassembler-and-debugger)
-------------------------------------------------------------------------------------------------------------------------------------------------------


To access the main JS code, the team:


* Unpacked the SFX archive
* Ran a command to collect the Node.js file
* Launched fjlpexyjauf.exe in x32dbg, entering the incoming data into the command line
* Got to the point where JS code execution started
* Located the code in memory and saved a dump


To see how the unpacking and dump extraction processes were conducted, refer to the original article. For this overview, let's focus on the code analysis.


### Analyzing the JS code[#](#analyzing-the-js-code)


The initially unintelligible JavaScript code was made clear by removing unnecessary bytes and using a JavaScript deobfuscator.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjRf55BvVtssMca4r_8d6Y_WM_08F5i6PqKYNZ26Zgo72LNeGeTFlx45yw-FwgQeaS5WcSkXm4V0vhPs3livUTR0waTC1Y5c6qEMJ3HFI0xdmUGFS6qoqAvioKocrHNVB6L_MczAbSZj3_U36SGN0SxDIo883_VdwFj28J31-2G0y2xP3-8jqIG7KD32K8/s728-rw-ft-e30/image07.png)
The code began with an array of encrypted strings. Then, specific elements were moved to the end of the array through manipulation. After that, a function was implemented to decrypt the array strings using an alternative form of BASE64 (T1132.002), followed by URL encode-decode, and finally, RC4.


**This function was called using two variables:**


1. An element from the array.


2. The RC4 key.


With the help of [a special script](https://github.com/anyrun/blog-scripts/blob/main/Extractors/Lu0Bot/decode_strings_Lu0Bot.py), the lines were decrypted, revealing that portions of the domains were hard-coded into the sample. 


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjKh_ug0P8xJ5jS8ZkiLN0OM-sNAWKiW1JAQeqmw0tYjKP8iCuR4EqXhFEjXriSpqgJxx-3QZcFmRMSlA2v6fiHxYPKx4PpgwI_mwfH4mynR8fIARyXRb7VBvqdxwmWqU7OkOmmnMe7jXuZmTdHpH7D4d0PeD-k2iL5VPMJ0S6GOOe9NUPaNB85pwoWQ4U/s728-rw-ft-e30/image08.png)
Following that, the section of the code responsible for assembling the domain was discovered.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEh4Q01iaRETT1c9d7xBkJrvZ5lY-1DbsPVTRazyAw38f1_OVU6XwP0u2Wr05GZrT4GNAkjzdbfm41o-42mI2UWpQeYFZ0p4jgs9GHcL49IumAEi7-7Ja0h3_aJ1rXJFFek4D3bgqFzdbr725J51dOhJNe_H6J_qekTd7UFdjXmbhChw4aCF3z2ZysTgR_M/s728-rw-ft-e30/image09.png)
### Debugging the JavaScript code[#](#debugging-the-javascript-code)


To debug, the team used Node.js with its inspect-brk parameter (node.exe –inspect-brk \*obfuscate dump without garbage bytes\*), placing a breakpoint on the "var" keyword and observing the output generated by each line.


It was found that the first function (**ginf**) gathered system information and produced a 15-element array with system details.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEjdMkkmqKdvA2E3-E92ABrOQ0nsS-BTCJGhKUTfUaIxzgoMc6cevws0mkiV4-qJi_PevclKVe77YKD_SW5YFLIrIRdv1m1UpIw-pmOjg1OSpYJZhFDOB6BrEHsOBbR2F6ksgHx288UrclhEGLzOwb2iT4IDBqQw_0H_IAOVO0WnbfgwKATS4msZ55tRjds/s728-rw-ft-e30/image10.png)
The second function (**hwco**) used the 15-element array from the **ginf** function as input, which generated an output comprising the tail-end of the domain until the dot. Further analysis revealed that this output was a hash of the gathered system data.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgs5dhnlTEbXghibgwc3-vZBiVGbttqzo7GCKegQfXM9eObujqb8bGV4POYpNe-64d0fAIbwVfuj2kdhDfjAT_jAUgZ4vu1KOTzqEF3_4CyleY5Md63LsJ-_DWh_t9ohIzZ3g8_Y7f6q61Xz38qFg9grcZFtRy-135-FTgUcSrmOVzC7VLhg2cuV0x6Ci4/s728-rw-ft-e30/image11.png)
The port, number, and domain segment after the dot were extracted from the acc array and then assigned to variables.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEj5u6CLn3dHsgmQBgMXQMgUv7oymY7JaQCopbaaPhUi2R_rjpCUxANP-U8kBq79qSA22V0aTPoboqw1KL-mbxKsbdoIBX1x0eZr6kdjrm2jnoRDCRQj8uc2BFMMqALkYARA6MbrjxigXLa2ia3qpKpnkbyRSqBf7RsZJMTMb8XlLBEvYqBBMJKAE9DCqTY/s728-rw-ft-e30/image12.png)
A random number was added to the domain segment after the dot. The next line selected an alternative domain if certain conditions were met.


![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEgdUJRw5FsGy6GTe-OS0jCGNwyRqbzZQ_10BaW08cQJNLyQjXz91pr5lWloFr1BJ9qADyR94vlsV3xq7iqETJ4u2tOEdF6kxIbaUxB44HUp4DG5jSitXrhac2DTS-2tXg0vcs3GBOMIJXsOfNL4SQ0VOI7wp68_Wgs-FjPWeaR67xWCA9jaTxmkiYXaQVw/s728-rw-ft-e30/image13.png)
After several other operations, the domain was fully assembled, and all necessary elements were packed into a JSON object.


[![](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEibKkDF6D0j2jOjDhi5YbVoN5uwftrzVIKxSk8fY5SdsBRcaTp_8FlNtyIwRgQfwlgb81CphOR3BRKtptkumgQxEE1z0bU5d6prnf08iXSgLUCaYKn3e7D3lQvc9MHthjbcCNufEN-mC7M9JxiNkWSbn9tduMyO-IlJSyMZLV4vnJS_mwRYWqlETor3KPY/s728-rw-ft-e30/table.jpg)](https://blogger.googleusercontent.com/img/b/R29vZ2xl/AVvXsEibKkDF6D0j2jOjDhi5YbVoN5uwftrzVIKxSk8fY5SdsBRcaTp_8FlNtyIwRgQfwlgb81CphOR3BRKtptkumgQxEE1z0bU5d6prnf08iXSgLUCaYKn3e7D3lQvc9MHthjbcCNufEN-mC7M9JxiNkWSbn9tduMyO-IlJSyMZLV4vnJS_mwRYWqlETor3KPY/s728-rw-ft-e30/table.jpg)
After executing, the malware searched for an address for data transmission. Once the server received the traffic, it sent JS code.


Lu0bot detection[#](#lu0bot-detection)
--------------------------------------


As part of their effort, the team managed to uncover a wealth of intelligence and IOCs, as well as wrote YARA, Sigma, and Suricata rules. You can access it in the article.


All of the findings were incorporated into ANY.RUN, enabling the service to quickly identify any Lu0Bot sample and reveal C2 domains after decrypting strings.


Conclusion[#](#conclusion)
--------------------------


Lu0bot is an unusual malware that combines Node.js and executable JS code. It possesses a unique domain structure and uses custom encryption methods for strings.


Although it currently exhibits a low level of activity, Lu0bot can pose a significant risk if its campaign scales and the C2 server starts actively responding.


Protect your organization from this and other malware by using [ANY.RUN](https://any.run/?utm_source=hacker_news&utm_medium=article&utm_campaign=lu0bot0928&utm_content=landing) to quickly analyze any suspicious files or links and get a conclusive verdict in seconds.


  





## Tags:
***MITRE IDs***: T1132.002

### Autogenerated tags:
[[malware]] [[lu0bot]] [[any.run]] [[node.js]] [[exe]] [[javascript]]
