# Hackers Targeting WebLogic Servers and Docker APIs for Mining Cryptocurrencies
## Researchers have uncovered two separate malicious cryptocurrency mining campaigns; one exploiting Oracle WebLogic servers and Docker APIs.
## Information:

+ Link: https://thehackernews.com/2022/09/hackers-targeting-weblogic-servers-and.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 16 September 2022, 10:58
+ Date scraped: 16 September 2022, 11:00

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh1sRBo_ZY7HgvKOAmX48Fm2WVmdgzaxlpLKjWJdIbcDmSPoMhKNRnvoEzs1CeLQfriVUkngqRhLj6-9awHtv_DcqbKgRbmXo_M_03xicrkKz34GxB6Z68bL51GfJszPQZSm7wdORW1UR-5UcTEgmW2YZ3RvbgUdobA9TKfRbeoXpG1vtvq1S-yeEcf/s728-e1000/crypto-mining.jpg)


Malicious actors such as Kinsing are taking advantage of both recently disclosed and older security flaws in Oracle WebLogic Server to deliver cryptocurrency-mining malware.


Cybersecurity company Trend Micro said it [found](https://www.trendmicro.com/en_us/research/22/i/a-post-exploitation-look-at-coinminers-abusing-weblogic-vulnerab.html) the financially-motivated group leveraging the vulnerability to drop Python scripts with capabilities to disable operating system (OS) security features such as Security-Enhanced Linux ([SELinux](https://www.redhat.com/en/topics/linux/what-is-selinux)), and others.


The operators behind the [Kinsing malware](https://www.cyberark.com/resources/threat-research-blog/kinsing-the-malware-with-two-faces) have a history of scanning for vulnerable servers to co-opt them into a botnet, including that of [Redis](https://www.trendmicro.com/en_us/research/20/d/exposed-redis-instances-abused-for-remote-code-execution-cryptocurrency-mining.html), [SaltStack](https://redcanary.com/blog/kinsing-malware-citrix-saltstack/), [Log4Shell](https://thehackernews.com/2022/04/hackers-exploiting-spring4shell.html), [Spring4Shell](https://thehackernews.com/2022/04/hackers-exploiting-spring4shell.html), and the Atlassian Confluence flaw ([CVE-2022-26134](https://thehackernews.com/2022/06/atlassian-confluence-flaw-being-used-to.html)).


The Kinsing actors have also been involved in campaigns against container environments via [misconfigured open Docker Daemon API ports](https://blog.aquasec.com/threat-alert-kinsing-malware-container-vulnerability) to launch a crypto miner and subsequently spread the malware to other containers and hosts.


The latest wave of attacks entails the actor weaponizing [CVE-2020-14882](https://nvd.nist.gov/vuln/detail/CVE-2020-14882) (CVSS score: 9.8), a two-year-old remote code execution (RCE) bug, against unpatched servers to seize control of the server and drop malicious payloads.


It's worth noting that the vulnerability has been [exploited in the past](https://thehackernews.com/2020/12/multiple-botnets-exploiting-critical.html) by multiple botnets to distribute Monero miners and the Tsunami backdoor on infected Linux systems. 


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh-utvgKxe36MyxmW2adubFVWxVKr-1Z4nJnB9nCLoIz72PJGF2D8Ti92uYdI0q1Y-KNK6paKazaUlHWRQZziPwY5119ANOJMXqaoGe4zOQOvqeEL1KkDD0Ed6TPx0FMjstH-f-8Sk0X--OysqaQnanHwm4INx3STYgUBwVWAo4Jzx5tnTWbKUt7EO4/s728-e100/hack.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEh-utvgKxe36MyxmW2adubFVWxVKr-1Z4nJnB9nCLoIz72PJGF2D8Ti92uYdI0q1Y-KNK6paKazaUlHWRQZziPwY5119ANOJMXqaoGe4zOQOvqeEL1KkDD0Ed6TPx0FMjstH-f-8Sk0X--OysqaQnanHwm4INx3STYgUBwVWAo4Jzx5tnTWbKUt7EO4/s728-e100/hack.jpg)
Successful exploitation of the flaw was succeeded by the deployment of a shell script that's responsible for a series of actions: Removing the [/var/log/syslog](https://help.ubuntu.com/community/LinuxLogFiles) system log, turning off security features and cloud service agents from Alibaba and Tencent, and killing competing miner processes.


The shell script then proceeds to download the Kinsing malware from a remote server, while also taking steps to ensure persistence by means of cron job.


"The successful exploitation of this vulnerability can lead to RCE, which can allow attackers to perform a plethora of malicious activities on affected systems," Trend Micro said. "This can range from malware execution [...] to theft of critical data, and even complete control of a compromised machine."


## **TeamTNT actors make a comeback with the Kangaroo Attack**


The development comes as researchers from Aqua Security identified three new attacks linked to another "vibrant" cryptojacking group called TeamTNT, which voluntarily shut shop in November 2021.


"TeamTNT has been scanning for a misconfigured Docker Daemon and deploying alpine, a vanilla container image, with a command line to download a shell script (k.sh) to a C2 server," Aqua Security researcher Assaf Morag [said](https://blog.aquasec.com/new-malware-in-the-cloud-by-teamtnt).


What's notable about the attack chain is that it appears to be designed to break [SECP256K1 encryption](https://en.bitcoin.it/wiki/Secp256k1), which, if successful, could give the actor the ability to calculate the keys to any cryptocurrency wallet. Put differently, the idea is to leverage the high but illegal computational power of its targets to run the ECDLP solver and get the key.


Two other attacks mounted by the group entail the exploitation of [exposed Redis servers](https://blog.aquasec.com/container-attacks-on-redis-servers) and misconfigured Docker APIs to deploy coin miners and Tsunami binaries.


TeamTNT's targeting of Docker REST APIs has been [well-documented](https://thehackernews.com/2021/12/ongoing-autom-cryptomining-malware.html) over the past year. But in an [operational security blunder](https://www.trendmicro.com/en_us/research/22/i/security-breaks-teamtnts-dockerhub-credentials-leak.html) spotted by Trend Micro, credentials associated with two of the attacker-controlled DockerHub accounts have been uncovered.


[![](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi0IY0nHIYVyoplfjBcUxHe2UQ8HJC-CQsXJZNKOFuXC17C5Qr6a4wRSM0arKFfc-z29j61GI_am83TJutj7s1RlsF0UQx0uq8dvuNfezG7wqD3PYDPqFHBO8m7qopVHCWrgR4GYVjM8c_OlyO6Fl0eUcrIcwH9vV7RwxB2-SpZb-AiOpx65Z7kdB1W/s728-e100/cyber.jpg)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEi0IY0nHIYVyoplfjBcUxHe2UQ8HJC-CQsXJZNKOFuXC17C5Qr6a4wRSM0arKFfc-z29j61GI_am83TJutj7s1RlsF0UQx0uq8dvuNfezG7wqD3PYDPqFHBO8m7qopVHCWrgR4GYVjM8c_OlyO6Fl0eUcrIcwH9vV7RwxB2-SpZb-AiOpx65Z7kdB1W/s728-e100/cyber.jpg)
The accounts – alpineos and sandeep078 – are said to have been used to distribute a variety of malicious payloads like rootkits, Kubernetes exploit kits, credential stealers, XMRig Monero miners, and even the Kinsing malware.


"The account alpineos was used in exploitation attempts on our honeypots three times, from mid-September to early October 2021, and we tracked the deployments' IP addresses to their location in Germany," Trend Micro's Nitesh Surana [said](https://www.trendmicro.com/en_us/research/22/i/security-breaks-teamtnts-dockerhub-credentials-leak.html).


"The threat actors were logged in to their accounts on the DockerHub registry and probably forgot to log out." Alternatively, "the threat actors logged in to their DockerHub account using the credentials of alpineos."


Trend Micro said the malicious alpineos image had been downloaded more than 150,000 times, adding it notified Docker about these accounts.


It's also recommending organizations to configure the exposed REST API with TLS to mitigate adversary-in-the-middle (AiTM) attacks, as well as use credential stores and [helpers](https://github.com/docker/docker-credential-helpers) to host user credentials.


  





## Tags:
***CVE's***: CVE-2020-14882 CVE-2022-26134

### Autogenerated tags:
[[malware]] [[kinsing]] [[teamtnt]] [[alpineos]] [[misconfigured]] [[dockerhub]]
