# Ransomware Attackers Use Microsoft-Signed Drivers to Gain Access to Systems
## Researchers reveal attackers use legitimate Microsoft-signed drivers in ransomware and malware campaigns against various companies
## Information:

+ Link: https://thehackernews.com/2022/12/ransomware-attackers-use-microsoft.html
+ Source: The Hacker News
+ Author: Ravie Lakshmanan
+ Date published: 14 December 2022, 13:08
+ Date scraped: 14 December 2022, 15:01

## Article:
![Main article image](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEhC0YFxPW0F2EEjjLE6yM4RNDX9FSsFi1dhqg80hvGRh9VoIyJAM7Hzps5d7KucdYEoH5bTuw-6PgEyd3ahi5H9PZvqC0bYVPYXggOWPeUNn4n116GZgb-TtmjmbWAKq5bi7Yd1T7Ni5j7uDCGc71vAGp6_KGUzCS6SuPGTHdrzzqPLvzXMmDgHGFYy/s728-e1000/windows.png)


Microsoft on Tuesday disclosed it took steps to suspend accounts that were used to publish malicious [drivers](https://learn.microsoft.com/en-us/windows-hardware/drivers/gettingstarted/what-is-a-driver-) that were certified by its Windows [Hardware Developer Program](https://partner.microsoft.com/en-us/dashboard/Registration/Hardware) were used to sign malware.


The tech giant said its investigation revealed the activity was restricted to a number of developer program accounts and that no further compromise was detected.


Cryptographically signing malware is concerning not least because it not only undermines a key security mechanism but also allows threat actors to subvert traditional detection methods and infiltrate target networks to perform highly privileged operations.


The probe, Redmond stated, was initiated after it was notified of rogue drivers being used in post-exploitation efforts, including deploying ransomware, by cybersecurity firms Mandiant, SentinelOne, and Sophos on October 19, 2022.


One notable aspect of these attacks was that the adversary had already obtained administrative privileges on compromised systems before using the drivers.


"Several developer accounts for the Microsoft Partner Center were engaged in submitting malicious drivers to obtain a Microsoft signature," Microsoft [explained](https://msrc.microsoft.com/update-guide/vulnerability/ADV220005). "A new attempt at submitting a malicious driver for signing on September 29, 2022, led to the suspension of the sellers' accounts in early October."


According to an analysis from Sophos threat actors affiliated with the [Cuba ransomware](https://thehackernews.com/2022/12/cuba-ransomware-extorted-over-60.html) (aka COLDDRAW) planted a malicious signed driver in a failed attempt at disabling endpoint detection tools via a novel malware loader dubbed BURNTCIGAR, which was [first revealed](https://www.mandiant.com/resources/blog/unc2596-cuba-ransomware) by Mandiant in February 2022.


The company also identified three variants of the driver signed by code signing certificates that belong to two Chinese companies, Zhuhai Liancheng Technology and Beijing JoinHope Image Technology.


The reasoning behind using signed drivers is that it offers a way for threat actors to get around [crucial security measures](https://learn.microsoft.com/en-us/windows-hardware/drivers/install/driver-signing) which require kernel-mode drivers to be signed in order for Windows to load the package. What's more, the technique misuses the de facto trust security tools place in Microsoft-attested drivers to their advantage.


"Threat actors are moving up the trust pyramid, attempting to use increasingly more well-trusted cryptographic keys to digitally sign their drivers," Sophos researchers Andreas Klopsch and Andrew Brandt [said](https://news.sophos.com/en-us/2022/12/13/signed-driver-malware-moves-up-the-software-trust-chain/). "Signatures from a large, trustworthy software publisher make it more likely the driver will load into Windows without hindrance."


[![Ransomware](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEgPn6pcUHz82SdGSZzh3s3Uea_Shcy_WAS6FHpr1R-7Y0iHX42Ovkp6EHvte5noobSnTuv-15WCVDKzbphHVsuk7Jjc5ZbweFCAz5M1EKEssunvne_RxkO7YtJdByJZS-VRVcUWZhrDaHD_m6WsnsLSGobkEXwvrf6vhEfeuZE0Ae5cn-pCWtnirLTK/s728-e100/driver-ransomware.png)
Google-owned Mandiant, in a coordinate disclosure, [said](https://www.mandiant.com/resources/blog/hunting-attestation-signed-malware) it observed a financially motivated threat group known as UNC3944 employing a loader named STONESTOP to install a malicious driver dubbed POORTRY that's designed to terminate processes associated with security software and delete files.


Stating that it has "continually observed threat actors use compromised, stolen, and illicitly purchased code-signing certificates to sign malware," the threat intelligence and incident response firm noted that "several distinct malware families, associated with distinct threat actors, have been signed with this process."


This has given rise to the possibility that these hacking groups could be leveraging a criminal service for code signing (i.e., malicious driver signing as a service), wherein the provider gets the malware artifacts signed through Microsoft's attestation process on behalf of the actors.


[![Ransomware](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAQAAAC1HAwCAAAAC0lEQVR42mP8Xw8AAoMBgDTD2qgAAAAASUVORK5CYII=)](https://thehackernews.com/new-images/img/b/R29vZ2xl/AVvXsEj4B0fOzTD_4kYBPayN9ywx8VjCJHukqioim03rUd_WlyNI6LLH1ViRx_qI6877jMvpJt0Te219W6kQ9jjD_MYeBipELbycKzkjiwohyj81r5Hs_FdhlGQbcjfmkHUkrIhoyz9OVogVtesUEOTKLw74Jt40BAq9tn3wBONZSHbOQYlmrl4DJ1rgKfeH/s728-e100/ransomware.png)
STONESTOP and POORTRY are said to have been used by UNC3944 in attacks aimed at telecommunication, BPO, MSSP, financial services, cryptocurrency, entertainment, and transportation sectors, SentinelOne [said](https://www.sentinelone.com/labs/driving-through-defenses-targeted-attacks-leverage-signed-malicious-microsoft-drivers/), adding a different threat actor utilized a similar signed driver that resulted in the deployment of [Hive ransomware](https://thehackernews.com/2022/11/hive-ransomware-attackers-extorted-100.html).


Microsoft has since revoked the certificates for impacted files and suspended the partners' seller accounts to counter the threats as part of its December 2022 [Patch Tuesday](https://thehackernews.com/2022/12/december-2022-patch-tuesday-get-latest.html) update.

 This is not the first time digital certificates have been abused to sign malware. Last year, a [Netfilter driver](https://thehackernews.com/2021/06/hackers-trick-microsoft-into-signing.html) certified by Microsoft turned out to be a malicious Windows rootkit that was observed communicating with command-and-control (C2) servers located in China.


It's not a Windows-only phenomenon, however, as Google this month [published](https://thehackernews.com/2022/12/hackers-sign-android-malware-apps-with.html) findings that compromised platform certificates managed by Android device makers including Samsung and LG had been used to sign malicious apps distributed through unofficial channels.


The development also comes amid a [broader](https://thehackernews.com/2022/09/ransomware-attackers-abuse-genshin.html) [abuse](https://thehackernews.com/2022/10/blackbyte-ransomware-abuses-vulnerable.html) of [signed drivers](https://thehackernews.com/2022/10/blackbyte-ransomware-abuses-vulnerable.html) to [sabotage security software](https://thehackernews.com/2022/11/new-earth-longzhi-apt-targets-ukraine.html) in recent months. The attack, referred to as Bring Your Own Vulnerable Driver (BYOVD), involves exploiting legitimate drivers that contain known shortcomings to escalate privileges and execute post-compromise actions.


Microsoft, in late October, [said](https://learn.microsoft.com/en-us/windows/security/threat-protection/windows-defender-application-control/microsoft-recommended-driver-block-rules) it's [enabling](https://support.microsoft.com/en-gb/topic/october-25-2022-kb5018496-os-build-22621-755-preview-64040bea-1e02-4b6d-bad1-b036200c2cb3) the vulnerable driver blocklist (DriverSiPolicy.p7b) by default for all devices with Windows 11 2022 update, alongside validating that it's the same across different operating system versions, following an Ars Technica [report](https://arstechnica.com/information-technology/2022/10/how-a-microsoft-blunder-opened-millions-of-pcs-to-potent-malware-attacks/) that highlighted inconsistencies in updating the blocklist for Windows 10 machines.


"Code signing mechanisms are an important feature in modern operating systems," SentinelOne said. "The introduction of driver signing enforcement was key in stemming the tide of rootkits for years. The receding effectiveness of code signing represents a threat to security and verification mechanisms at all OS layers."


  





## Tags:


### Autogenerated tags:
[[microsoft]] [[malware]] [[windows]] [[ransomware]] [[mandiant]] [[sentinelone]] [[sophos]]
